@@ -57,7 +57,22 @@ class RowsEvent(BinLogEvent):
                 self.event_type == BINLOG.DELETE_ROWS_EVENT_V2 or \
                 self.event_type == BINLOG.UPDATE_ROWS_EVENT_V2:
                 self.flags, self.extra_data_length = struct.unpack('<HH', self.packet.read(4))
-                self.extra_data = self.packet.read(self.extra_data_length / 8)
+                if self.extra_data_length > 2:
+                    self.extra_data_type = struct.unpack('<B', self.packet.read(1))[0]
+
+                    # ndb information
+                    if self.extra_data_type == 0:
+                        self.nbd_info_length, self.nbd_info_format = struct.unpack('<BB', self.packet.read(1))
+                        self.nbd_info = self.packet.read(self.nbd_info_length - 2)
+                    # partition information
+                    elif self.extra_data_type == 1:
+                        if self.event_type == BINLOG.UPDATE_ROWS_EVENT_V2:
+                            self.partition_id, self.source_partition_id = struct.unpack('<HH', self.packet.read(4))
+                        else:
+                            self.partition_id = struct.unpack('<H', self.packet.read(2))[0]
+                    # etc
+                    else:
+                        self.extra_data = self.packet.read(self.extra_info_length - 3)
         else:
             self.flags = struct.unpack('<H', self.packet.read(2))[0]
 
@@ -92,6 +107,7 @@ class RowsEvent(BinLogEvent):
             column = self.columns[i]
             name = self.table_map[self.table_id].columns[i].name
             unsigned = self.table_map[self.table_id].columns[i].unsigned
+            zerofill = self.table_map[self.table_id].columns[i].zerofill
 
             if BitGet(cols_bitmap, i) == 0:
                 values[name] = None
@@ -102,21 +118,29 @@ class RowsEvent(BinLogEvent):
             elif column.type == FIELD_TYPE.TINY:
                 if unsigned:
                     values[name] = struct.unpack("<B", self.packet.read(1))[0]
+                    if zerofill:
+                        values[name] = format(values[name], '03d')
                 else:
                     values[name] = struct.unpack("<b", self.packet.read(1))[0]
             elif column.type == FIELD_TYPE.SHORT:
                 if unsigned:
                     values[name] = struct.unpack("<H", self.packet.read(2))[0]
+                    if zerofill:
+                        values[name] = format(values[name], '05d')
                 else:
                     values[name] = struct.unpack("<h", self.packet.read(2))[0]
             elif column.type == FIELD_TYPE.LONG:
                 if unsigned:
                     values[name] = struct.unpack("<I", self.packet.read(4))[0]
+                    if zerofill:
+                        values[name] = format(values[name], '010d')
                 else:
                     values[name] = struct.unpack("<i", self.packet.read(4))[0]
             elif column.type == FIELD_TYPE.INT24:
                 if unsigned:
                     values[name] = self.packet.read_uint24()
+                    if zerofill:
+                        values[name] = format(values[name], '08d')
                 else:
                     values[name] = self.packet.read_int24()
             elif column.type == FIELD_TYPE.FLOAT:
@@ -155,6 +179,8 @@ class RowsEvent(BinLogEvent):
             elif column.type == FIELD_TYPE.LONGLONG:
                 if unsigned:
                     values[name] = self.packet.read_uint64()
+                    if zerofill:
+                        values[name] = format(values[name], '020d')
                 else:
                     values[name] = self.packet.read_int64()
             elif column.type == FIELD_TYPE.YEAR:
@@ -274,11 +300,11 @@ class RowsEvent(BinLogEvent):
             data = ~data + 1
 
         t = datetime.timedelta(
-            hours=sign*self.__read_binary_slice(data, 2, 10, 24),
+            hours=self.__read_binary_slice(data, 2, 10, 24),
             minutes=self.__read_binary_slice(data, 12, 6, 24),
             seconds=self.__read_binary_slice(data, 18, 6, 24),
             microseconds=self.__read_fsp(column)
-        )
+        ) * sign
         return t
 
     def __read_date(self):
