@@ -291,7 +291,7 @@ class TestDataType(base.PyMySQLReplicationTestCase):
             microseconds=(((838*60) + 59)*60 + 59)*1000000
         ))
         self.assertEqual(event.rows[0]["values"]["test2"], datetime.timedelta(
-            microseconds=(((-838*60) + 59)*60 + 59)*1000000
+            microseconds=-(((838*60) + 59)*60 + 59)*1000000
         ))
 
     def test_time2(self):
@@ -306,7 +306,7 @@ class TestDataType(base.PyMySQLReplicationTestCase):
             microseconds=(((838*60) + 59)*60 + 59)*1000000 + 0
         ))
         self.assertEqual(event.rows[0]["values"]["test2"], datetime.timedelta(
-            microseconds=(((-838*60) + 59)*60 + 59)*1000000 + 0
+            microseconds=-(((838*60) + 59)*60 + 59)*1000000 + 0
         ))
 
     def test_zero_time(self):
@@ -609,6 +609,37 @@ class TestDataType(base.PyMySQLReplicationTestCase):
         event = self.create_and_insert_value(create_query, insert_query)
         self.assertMultiLineEqual(event.rows[0]["values"]["test"], string)
 
+    def test_zerofill(self):
+        create_query = "CREATE TABLE test ( \
+            test TINYINT UNSIGNED ZEROFILL DEFAULT NULL, \
+            test2 SMALLINT UNSIGNED ZEROFILL DEFAULT NULL, \
+            test3 MEDIUMINT UNSIGNED ZEROFILL DEFAULT NULL, \
+            test4 INT UNSIGNED ZEROFILL DEFAULT NULL, \
+            test5 BIGINT UNSIGNED ZEROFILL DEFAULT NULL \
+            )"
+        insert_query = "INSERT INTO test (test, test2, test3, test4, test5) VALUES(1, 1, 1, 1, 1)"
+        event = self.create_and_insert_value(create_query, insert_query)
+        self.assertEqual(event.rows[0]["values"]["test"], '001')
+        self.assertEqual(event.rows[0]["values"]["test2"], '00001')
+        self.assertEqual(event.rows[0]["values"]["test3"], '00000001')
+        self.assertEqual(event.rows[0]["values"]["test4"], '0000000001')
+        self.assertEqual(event.rows[0]["values"]["test5"], '00000000000000000001')
+
+    def test_partition_id(self):
+        if not self.isMySQL80AndMore():
+            self.skipTest("Not supported in this version of MySQL")
+        create_query = "CREATE TABLE test (id INTEGER) \
+            PARTITION BY RANGE (id) ( \
+                PARTITION p0 VALUES LESS THAN (1),   \
+                PARTITION p1 VALUES LESS THAN (2),   \
+                PARTITION p2 VALUES LESS THAN (3),   \
+                PARTITION p3 VALUES LESS THAN (4),   \
+                PARTITION p4 VALUES LESS THAN (5)    \
+            )"
+        insert_query = "INSERT INTO test (id) VALUES(3)"
+        event = self.create_and_insert_value(create_query, insert_query)
+        self.assertEqual(event.extra_data_type, 1)
+        self.assertEqual(event.partition_id, 3)
 
 if __name__ == "__main__":
     unittest.main()
